==> dl-0.0.1.tgz: package/lib/cdf/CdfTemplate.js <==
var Class = require("core").Class;
var Types = require("core").Common.Types;
var CdfDatasource = require("./CdfDatasource.js").CdfDatasource;

/**
 * @class CdfTemplate
 */
var CdfTemplate = function(){

    this.name = null;
    this.role = null;
    this.kind = null;
    this.data = null;

    this.children = [];
    

    this.initialize = function(name){
        this.name = name;
    };
    
    this.addChild = function(cdfTemplate){
        this.children.push(cdfTemplate);
    };
    
    this.getChild = function(name){
        for(var i=0,max=this.children.length;i<max;i++){
            if(this.children[i].name==name){
                return this.children[i];
            }
        }
        return null;
    };
    
    this.toJSON = function(){
        
        var retVal = {}, i, max;
        
        retVal[this.name] = {
            "role": this.role,
            "kind": this.kind            
        };
        
        if(this.children.length>0){
            
            if(Types.isInstanceOf(this.data, CdfDatasource)){
                throw "Template: '"+this.name+"' can't have CHILDREN and REMOTE_DATA together!";
            } else if(this.data){
                 retVal[this.name].data = this.data;
            } else {
                retVal[this.name].data = {};
            }
            
            retVal[this.name].data['#body'] = [];
            for(i=0,max=this.children.length;i<max;i++){
                retVal[this.name].data['#body'].push(this.children[i].name);
            }
            
        } else if(Types.isInstanceOf(this.data, CdfDatasource)){
            retVal[this.name]['#data'] = this.data.toJSON();
            
        } else if(this.data){
            retVal[this.name]['data'] = this.data;
        }
        
        for(i=0,max=this.children.length;i<max;i++){
            var renderedChild = this.children[i].toJSON();
            for(var elem in renderedChild){
                if(renderedChild.hasOwnProperty(elem)){
                    retVal[elem] = renderedChild[elem];
                }
            }
        }

        return retVal;
    };
    
    this.toString = function(indent){
        return JSON.stringify(this.toJSON(), null, (indent || 4));
    }
    
};

CdfTemplate = new Class( new CdfTemplate() );
exports.CdfTemplate = CdfTemplate;

==> dl-0.0.3.tgz: package/lib/cdf/CdfTemplate.js <==
var Class = require("core").Class;
var Types = require("core").Common.Types;
var CdfDatasource = require("./CdfDatasource.js").CdfDatasource;

/**
 * @class CdfTemplate
 */
var CdfTemplate = function(){

    this.name = null;
    this.role = null;
    this.kind = null;
    this.data = null;

    this.children = [];
    

    this.initialize = function(name){
        this.name = name;
    };
    
    this.addChild = function(cdfTemplate){
        this.children.push(cdfTemplate);
    };
    
    this.getChild = function(name){
        for(var i=0,max=this.children.length;i<max;i++){
            if(this.children[i].name==name){
                return this.children[i];
            }
        }
        return null;
    };
    
    this.toJSON = function(){
        
        var retVal = {}, i, max;
        
        retVal[this.name] = {
            "role": this.role,
            "kind": this.kind            
        };
        
        if(this.children.length>0){
            
            if(Types.isInstanceOf(this.data, CdfDatasource)){
                throw "Template: '"+this.name+"' can't have CHILDREN and REMOTE_DATA together!";
            } else if(this.data){
                 retVal[this.name].data = this.data;
            } else {
                retVal[this.name].data = {};
            }
            
            retVal[this.name].require = [];
            for(i=0,max=this.children.length;i<max;i++){
                retVal[this.name].require.push(this.children[i].name);
            }          
            
            
        } else if(Types.isInstanceOf(this.data, CdfDatasource)){
            retVal[this.name]['#data'] = this.data.toJSON();
            
        } else if(this.data){
            retVal[this.name]['data'] = this.data;
        }
        
        for(i=0,max=this.children.length;i<max;i++){
            var renderedChild = this.children[i].toJSON();
            for(var elem in renderedChild){
                if(renderedChild.hasOwnProperty(elem)){
                    retVal[elem] = renderedChild[elem];
                }
            }
        }

        return retVal;
    };
    
    this.toString = function(indent){
        return JSON.stringify(this.toJSON(), null, (indent || 4));
    }
    
};

CdfTemplate = new Class( new CdfTemplate() );
exports.CdfTemplate = CdfTemplate;
